@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cassava
 version: 0.4.5.0
-id: cassava-0.4.5.0-5561f7a2cf4fbc4e852eacf71d5b8fea
-key: cassa_JwfoPeUsgdT5QHwlI8utaR
+id: cassava-0.4.5.0-d0a0c0db804530a092b2cfb0925f3f97
+key: cassa_E9sQmhNHOsiBLLIlNy4HBB
 license: BSD3
 copyright: (c) 2012 Johan Tibell
            (c) 2012 Bryan O'\''Sullivan
@@ -26,12 +26,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cassava-0.4.5.0
-hs-libraries: HScassava-0.4.5.0-JwfoPeUsgdT5QHwlI8utaR
+hs-libraries: HScassava-0.4.5.0-E9sQmhNHOsiBLLIlNy4HBB
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
